# schmelzen


[![image](https://img.shields.io/pypi/v/schmelzen.svg)](https://pypi.python.org/pypi/schmelzen)
[![image](https://img.shields.io/conda/vn/conda-forge/schmelzen.svg)](https://anaconda.org/conda-forge/schmelzen)


**Merge multiple embeddings.**


-   Free software: GNU General Public License v3
-   Documentation: https://JRR3.github.io/schmelzen
    

## Features

-   TODO
